;; Copyright 1995 Crack dot Com,  All Rights reserved
;; See licensing information for more details on usage rights


;; this stuff ids in the registered version

(setq DFRIS_BULLET       SHOTGUN_BULLET)
(setq PLASMAGUN_BULLET   SHOTGUN_BULLET)
(setq LSABER_BULLET      SHOTGUN_BULLET)


(setq PLASMA_ICON20      MBULLET_ICON5)
(setq PLASMA_ICON50      MBULLET_ICON5)
(setq LSABER_ICON50      MBULLET_ICON5)
(setq LSABER_ICON100     MBULLET_ICON5)
(setq DFRIS_ICON4        MBULLET_ICON5)
(setq DFRIS_ICON10       MBULLET_ICON5)


(defun dfris_ai () nil)
