(select (random 4)
    (0 (setq net_levels
        '("netlevel/2play1.spe"
          "netlevel/2play2.spe"
          "netlevel/2play3.spe"
          "netlevel/2play4.spe"
          "netlevel/alitlhot.spe"
          "netlevel/getcross.spe"
          "netlevel/spacytdm.spe"
          "netlevel/treesmal.spe"
          "netlevel/redgrndm.spe"
          "netlevel/bugssml.spe"
          "netlevel/kotcross.spe"
          "netlevel/ruins.spe"
          "netlevel/occult.spe"
          "netlevel/cistern.spe")))
    (1 (setq net_levels
        '("netlevel/treesmal.spe"
          "netlevel/cistern.spe"
          "netlevel/bugssml.spe"
          "netlevel/occult.spe"
          "netlevel/redgrndm.spe"
          "netlevel/2play4.spe"
          "netlevel/getcross.spe"
          "netlevel/2play2.spe"
          "netlevel/2play3.spe"
          "netlevel/spacytdm.spe"
          "netlevel/2play1.spe"
          "netlevel/ruins.spe"
          "netlevel/kotcross.spe"
          "netlevel/alitlhot.spe")))
    (2 (setq net_levels
        '("netlevel/kotcross.spe"
          "netlevel/2play4.spe"
          "netlevel/spacytdm.spe"
          "netlevel/2play2.spe"
          "netlevel/cistern.spe"
          "netlevel/redgrndm.spe"
          "netlevel/treesmal.spe"
          "netlevel/alitlhot.spe"
          "netlevel/2play1.spe"
          "netlevel/occult.spe"
          "netlevel/getcross.spe"
          "netlevel/ruins.spe"
          "netlevel/2play3.spe"
          "netlevel/bugssml.spe")))
    (3 (setq net_levels
        '("netlevel/ruins.spe"
          "netlevel/getcross.spe"
          "netlevel/treesmal.spe"
          "netlevel/2play3.spe"
          "netlevel/2play2.spe"
          "netlevel/cistern.spe"
          "netlevel/kotcross.spe"
          "netlevel/2play1.spe"
          "netlevel/alitlhot.spe"
          "netlevel/2play4.spe"
          "netlevel/redgrndm.spe"
          "netlevel/spacytdm.spe"
          "netlevel/occult.spe"
          "netlevel/bugssml.spe"))))

