;; Foreground

(load_tiles
          "addon/newart/frabs_1.spe"
	    "addon/newart/frabs_2.spe"
	    "addon/newart/final.spe"
	    "addon/newart/mtile.spe"
	    "addon/newart/stones.spe"
)

;; Background

(load_tiles
          "addon/newart/frbsblue.spe"
	    "addon/newart/blcave.spe"
	    "addon/newart/space.spe"
)