(select (random 4)
    (0 (setq net_levels
        '("netlevel/4play1.spe"
          "netlevel/4play2.spe"
          "netlevel/4play3.spe"
          "netlevel/4play4.spe"
          "netlevel/spacymed.spe"
          "netlevel/teardrop.spe"
          "netlevel/aquarius.spe"
          "netlevel/madrace.spe"
          "netlevel/laazrckt.spe"
          "netlevel/bugsmed.spe"
          "netlevel/00dm.spe")))
    (1 (setq net_levels
        '("netlevel/aquarius.spe"
          "netlevel/madrace.spe"
          "netlevel/4play1.spe"
          "netlevel/4play2.spe"
          "netlevel/bugsmed.spe"
          "netlevel/teardrop.spe"
          "netlevel/laazrckt.spe"
          "netlevel/4play3.spe"
          "netlevel/00dm.spe"
          "netlevel/4play4.spe"
          "netlevel/spacymed.spe")))
    (2 (setq net_levels
        '("netlevel/laazrckt.spe"
          "netlevel/00dm.spe"
          "netlevel/4play3.spe"
          "netlevel/bugsmed.spe"
          "netlevel/4play4.spe"
          "netlevel/aquarius.spe"
          "netlevel/4play1.spe"
          "netlevel/spacymed.spe"
          "netlevel/4play2.spe"
          "netlevel/teardrop.spe"
          "netlevel/madrace.spe")))
    (3 (setq net_levels
        '("netlevel/teardrop.spe"
          "netlevel/4play4.spe"
          "netlevel/laazrckt.spe"
          "netlevel/spacymed.spe"
          "netlevel/bugsmed.spe"
          "netlevel/4play2.spe"
          "netlevel/4play3.spe"
          "netlevel/00dm.spe"
          "netlevel/madrace.spe"
          "netlevel/4play1.spe"
          "netlevel/aquarius.spe"))))

