;; Copyright 1999 Profound Corp,  All Rights reserved
;; See licensing information for more details on usage rights


(setq change_on_pickup true)
(setq skip_trainer_level false)
(setq switch_to_powerful true)
(setq mouse_can_switch true)
(setq enableammoandweapons 1)